==> 1.0.0.tar.gz: lib/src/lexer/InputStream.dart <==
import 'dart:io';

import 'CustomExceptions.dart';

class InputStream {
  String _str;
  int _lineLoc;
  int _charLoc;

  InputStream() {
    this._str = "";
    this._lineLoc = 1;
    this._charLoc = 0;
  }

  Future<void> load(String fileName) async {
    await processFile(fileName);
  }

  void loadSync(String fileName) {
    processFileSync(fileName);
  }

  void loadStr(String str) {
    _str = str.replaceAll('\r\n', '\n') + '\n';
  }

  Future<void> processFile(String fileName) async {
    try {
      _str = (await File(fileName).readAsString()).replaceAll('\r\n', '\n') + '\n'; // necessary to convert line endings from windows
    }
    on FileSystemException {
      throw FileDoesNotExist(fileName);
    }
  }

  void processFileSync(String fileName) {
    try {
      _str = (File(fileName).readAsStringSync()).replaceAll('\r\n', '\n') + '\n'; // necessary to convert line endings from windows
    }
    on FileSystemException {
      throw FileDoesNotExist(fileName);
    }
  }

  String nextChar() {
    return _str[_charLoc + 1];
  }

  String prevChar() {
    return _str[_charLoc - 1];
  }

  String currentChar() {
    if (_charLoc >= _str.length)
      throw FormatException("At file's end");
    return _str[_charLoc];
  }

  void advance() {
    if (this.currentChar() == '\n')
      _lineLoc++;
    _charLoc++;
  }

  void stepBack() {
    if (this.currentChar() == '\n')
      _lineLoc--;
    _charLoc--;
  }

  String toString() {
    return _str;
  }

  int get charLoc => _charLoc;
  int get lineLoc => _lineLoc;
}

==> 1.1.1.tar.gz: lib/src/lexer/InputStream.dart <==
import 'dart:io';

import 'CustomExceptions.dart';

class InputStream {
  String _str;
  int _lineLoc;
  int _charLoc;

  InputStream() {
    this._str = "";
    this._lineLoc = 1;
    this._charLoc = 0;
  }

  Future<void> load(String fileName) async {
    await processFile(fileName);
  }

  void loadSync(String fileName) {
    processFileSync(fileName);
  }

  void loadStr(String str) {
    _str = str.replaceAll('\r\n', '\n') + '\n';
  }

  Future<void> processFile(String fileName) async {
    try {
      _str = (await File(fileName).readAsString()).replaceAll('\r\n', '\n') +
          '\n'; // necessary to convert line endings from windows
    } on FileSystemException {
      throw FileDoesNotExist(fileName);
    }
  }

  void processFileSync(String fileName) {
    try {
      _str = (File(fileName).readAsStringSync()).replaceAll('\r\n', '\n') +
          '\n'; // necessary to convert line endings from windows
    } on FileSystemException {
      throw FileDoesNotExist(fileName);
    }
  }

  String nextChar() {
    return _str[_charLoc + 1];
  }

  String prevChar() {
    return _str[_charLoc - 1];
  }

  String currentChar() {
    if (_charLoc >= _str.length) {
      throw FormatException("At file's end");
    }
    return _str[_charLoc];
  }

  void advance() {
    if (this.currentChar() == '\n') {
      _lineLoc++;
    }
    _charLoc++;
  }

  void stepBack() {
    if (this.currentChar() == '\n') {
      _lineLoc--;
    }
    _charLoc--;
  }

  String toString() {
    return _str;
  }

  int get charLoc => _charLoc;
  int get lineLoc => _lineLoc;
}
